instrumenttools.transpose_from_sounding_pitch_to_fingered_pitch
===============================================================

.. autofunction:: abjad.tools.instrumenttools.transpose_from_sounding_pitch_to_fingered_pitch.transpose_from_sounding_pitch_to_fingered_pitch
   :noindex:
